[Libreoffice-commits] core.git: include/editeng include/sfx2 vcl/osx vcl/source vcl/unx

Tor Lillqvist tml at collabora.com
Sun Feb 12 11:01:00 UTC 2017


 include/editeng/svxacorr.hxx               |    2 +-
 include/sfx2/emojiview.hxx                 |    2 +-
 vcl/osx/salframeview.mm                    |    2 +-
 vcl/source/font/fontcharmap.cxx            |    4 ++--
 vcl/source/gdi/pdfwriter_impl.cxx          |    2 +-
 vcl/source/outdev/font.cxx                 |    4 ++--
 vcl/unx/generic/fontmanager/fontconfig.cxx |   18 +++++++++---------
 7 files changed, 17 insertions(+), 17 deletions(-)

New commits:
commit 6d15d4a6f6fbc163001ec082d55404481e64bed1
Author: Tor Lillqvist <tml at collabora.com>
Date:   Sun Feb 12 12:55:00 2017 +0200

    Get rid of "unicodes" in lower-case, too
    
    Instead, use "code points" (if you mean full 21-bit Unicode code
    points), or "code units" (if you mean the 16-bit units that make up
    UTF-16). Hopefully I got it right which one was meant in each case
    here.
    
    Change-Id: I8ee7a98996f1cebcfb95cd7d18a56570e48fa390

diff --git a/include/editeng/svxacorr.hxx b/include/editeng/svxacorr.hxx
index beecd96..23b85d4 100644
--- a/include/editeng/svxacorr.hxx
+++ b/include/editeng/svxacorr.hxx
@@ -73,7 +73,7 @@ const long ChgWordLstLoad   = 0x20000000;   // Replacement list loaded
 const long CplSttLstLoad    = 0x40000000;   // Exception list for Capital letters Start loaded
 const long WrdSttLstLoad    = 0x80000000;   // Exception list for Word Start loaded
 
-// TODO: handle unicodes > U+FFFF and check users of this class
+// TODO: handle code points > U+FFFF and check users of this class
 
 // only a mapping class
 class EDITENG_DLLPUBLIC SvxAutoCorrDoc
diff --git a/include/sfx2/emojiview.hxx b/include/sfx2/emojiview.hxx
index adb8306..1b0d0ac 100644
--- a/include/sfx2/emojiview.hxx
+++ b/include/sfx2/emojiview.hxx
@@ -59,7 +59,7 @@ public:
 
     virtual ~EmojiView () override;
 
-    // Fill view with emoji unicodes
+    // Fill view with emojis
     void Populate ();
 
     void setInsertEmojiHdl (const Link<ThumbnailViewItem*, void> &rLink);
diff --git a/vcl/osx/salframeview.mm b/vcl/osx/salframeview.mm
index 1b16485..15d5733 100644
--- a/vcl/osx/salframeview.mm
+++ b/vcl/osx/salframeview.mm
@@ -1550,7 +1550,7 @@ SAL_WNODEPRECATED_DECLARATIONS_POP
         }
         if( nKeyCode != 0 )
         {
-            // don't send unicodes in the private use area
+            // don't send code points in the private use area
             if( keyChar >= 0xf700 && keyChar < 0xf780 )
                 keyChar = 0;
             BOOL bRet = [self sendKeyToFrameDirect: nKeyCode character: keyChar modifiers: mpFrame->mnLastModifierFlags];
diff --git a/vcl/source/font/fontcharmap.cxx b/vcl/source/font/fontcharmap.cxx
index fa0fb5b..f30c4e6 100644
--- a/vcl/source/font/fontcharmap.cxx
+++ b/vcl/source/font/fontcharmap.cxx
@@ -287,7 +287,7 @@ bool ParseCMAP( const unsigned char* pCmap, int nLength, CmapResult& rResult )
 
     if( aConverter && aCvtContext )
     {
-        // determine the set of supported unicodes from encoded ranges
+        // determine the set of supported code points from encoded ranges
         std::set<sal_UCS4> aSupportedCodePoints;
 
         static const int NINSIZE = 64;
@@ -327,7 +327,7 @@ bool ParseCMAP( const unsigned char* pCmap, int nLength, CmapResult& rResult )
         rtl_destroyTextToUnicodeConverter( aCvtContext );
         rtl_destroyTextToUnicodeConverter( aConverter );
 
-        // convert the set of supported unicodes to ranges
+        // convert the set of supported code points to ranges
         std::vector<sal_UCS4> aSupportedRanges;
 
         std::set<sal_UCS4>::const_iterator itChar = aSupportedCodePoints.begin();
diff --git a/vcl/source/gdi/pdfwriter_impl.cxx b/vcl/source/gdi/pdfwriter_impl.cxx
index dce4752..13bd2fe 100644
--- a/vcl/source/gdi/pdfwriter_impl.cxx
+++ b/vcl/source/gdi/pdfwriter_impl.cxx
@@ -3097,7 +3097,7 @@ sal_Int32 PDFWriterImpl::createToUnicodeCMap( sal_uInt8* pEncoding,
             aContents.append( '<' );
             appendHex( (sal_Int8)pEncoding[n], aContents );
             aContents.append( "> <" );
-            // TODO: handle unicodes>U+FFFF
+            // TODO: handle code points>U+FFFF
             sal_Int32 nIndex = pEncToUnicodeIndex[n];
             for( sal_Int32 j = 0; j < pCodeUnitsPerGlyph[n]; j++ )
             {
diff --git a/vcl/source/outdev/font.cxx b/vcl/source/outdev/font.cxx
index cea5665..1c04f05 100644
--- a/vcl/source/outdev/font.cxx
+++ b/vcl/source/outdev/font.cxx
@@ -1377,7 +1377,7 @@ SalLayout* OutputDevice::ImplGlyphFallbackLayout( SalLayout* pSalLayout, ImplLay
     rLayoutArgs.PrepareFallback();
     rLayoutArgs.mnFlags |= SalLayoutFlags::ForFallback;
 
-    // get list of unicodes that need glyph fallback
+    // get list of code units that need glyph fallback
     int nCharPos = -1;
     bool bRTL = false;
     OUStringBuffer aMissingCodeBuf;
@@ -1388,7 +1388,7 @@ SalLayout* OutputDevice::ImplGlyphFallbackLayout( SalLayout* pSalLayout, ImplLay
 
     FontSelectPattern aFontSelData = mpFontInstance->maFontSelData;
 
-    // try if fallback fonts support the missing unicodes
+    // try if fallback fonts support the missing code units
     for( int nFallbackLevel = 1; nFallbackLevel < MAX_FALLBACK; ++nFallbackLevel )
     {
         // find a font family suited for glyph fallback
diff --git a/vcl/unx/generic/fontmanager/fontconfig.cxx b/vcl/unx/generic/fontmanager/fontconfig.cxx
index 9a58e91..120a116 100644
--- a/vcl/unx/generic/fontmanager/fontconfig.cxx
+++ b/vcl/unx/generic/fontmanager/fontconfig.cxx
@@ -948,12 +948,12 @@ void PrintFontManager::Substitute( FontSelectPattern &rPattern, OUString& rMissi
     // Add required Unicode characters, if any
     if ( !rMissingCodes.isEmpty() )
     {
-        FcCharSet *unicodes = FcCharSetCreate();
+        FcCharSet *codePoints = FcCharSetCreate();
         for( sal_Int32 nStrIndex = 0; nStrIndex < rMissingCodes.getLength(); )
         {
             // also handle unicode surrogates
             const sal_uInt32 nCode = rMissingCodes.iterateCodePoints( &nStrIndex );
-            FcCharSetAddChar( unicodes, nCode );
+            FcCharSetAddChar( codePoints, nCode );
             //if the codepoint is impossible for this lang tag, then clear it
             //and autodetect something useful
             if (!aLangAttrib.isEmpty() && isImpossibleCodePointForLang(aLangTag, nCode))
@@ -965,8 +965,8 @@ void PrintFontManager::Substitute( FontSelectPattern &rPattern, OUString& rMissi
                 aLangAttrib = mapToFontConfigLangTag(aLangTag);
             }
         }
-        FcPatternAddCharSet(pPattern, FC_CHARSET, unicodes);
-        FcCharSetDestroy(unicodes);
+        FcPatternAddCharSet(pPattern, FC_CHARSET, codePoints);
+        FcCharSetDestroy(codePoints);
     }
 
     if (!aLangAttrib.isEmpty())
@@ -1065,19 +1065,19 @@ void PrintFontManager::Substitute( FontSelectPattern &rPattern, OUString& rMissi
                 }
             }
 
             // update rMissingCodes by removing resolved unicodes
             if( !rMissingCodes.isEmpty() )
             {
                 std::unique_ptr<sal_uInt32[]> const pRemainingCodes(new sal_uInt32[rMissingCodes.getLength()]);
                 int nRemainingLen = 0;
-                FcCharSet* unicodes;
-                if (!FcPatternGetCharSet(pSet->fonts[0], FC_CHARSET, 0, &unicodes))
+                FcCharSet* codePoints;
+                if (!FcPatternGetCharSet(pSet->fonts[0], FC_CHARSET, 0, &codePoints))
                 {
                     for( sal_Int32 nStrIndex = 0; nStrIndex < rMissingCodes.getLength(); )
                     {
-                        // also handle unicode surrogates
+                        // also handle surrogates
                         const sal_uInt32 nCode = rMissingCodes.iterateCodePoints( &nStrIndex );
-                        if (FcCharSetHasChar(unicodes, nCode) != FcTrue)
+                        if (FcCharSetHasChar(codePoints, nCode) != FcTrue)
                             pRemainingCodes[ nRemainingLen++ ] = nCode;
                     }
                 }
@@ -1065,19 +1065,19 @@ void PrintFontManager::Substitute( FontSelectPattern &rPattern, OUString& rMissi
             }
 
-            // update rMissingCodes by removing resolved unicodes
+            // update rMissingCodes by removing resolved code points
             if( !rMissingCodes.isEmpty() )
             {


More information about the Libreoffice-commits mailing list